@@ -1,3 +1,6 @@
+{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE UndecidableInstances #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Monoid.Endomorphism
@@ -19,7 +22,7 @@ import           Data.Group
 import           Data.Groupoid
 import           Data.Semigroup
 import           Data.Semigroupoid
-import           Prelude           ()
+import           Prelude           (Show)
 
 -- | An 'Endomorphism' in a given 'Category' is a morphism from some
 --   object to itself.  The set of endomorphisms for a particular
@@ -27,6 +30,8 @@ import           Prelude           ()
 --   and the identity morphism as the identity element.
 newtype Endomorphism k a = Endomorphism {getEndomorphism :: k a a}
 
+deriving instance Show (k a a) =>  Show (Endomorphism k a)
+
 instance Semigroupoid k => Semigroup (Endomorphism k a) where
   Endomorphism a <> Endomorphism b = Endomorphism (a `o` b)
 
